==> networked-aframe-0.8.0.tgz: package/CONTRIBUTING.md <==
[slack]: https://aframe.io/slack-invite/
[issues]: https://github.com/networked-aframe/networked-aframe/issues
[hayden]: https://twitter.com/HaydenLee37

Interested in contributing? As an open source project, we'd appreciate any help
and contributions! On top of the Networked-Aframe framework itself, you can also
contribute to this related component:

- [aframe-lerp-component](https://github.com/haydenjameslee/aframe-lerp-component)

# Join the Community on Slack

1. [Invite yourself][slack] to the A-Frame Slack channel.
2. [Join the A-Frame slack](https://aframevr.slack.com)
3. Join the #networked-aframe channel

# Get Help or Ask a Question

If you're not sure how to do something with Networked-Aframe, please post a question
(and any code you've tried so far) to [Github Issues][issues]. <!-- Questions there will automatically create notifications in [Slack][slack], and are easier for others to find so new developers can learn from your questions too. -->

# File an Issue

1. Search the [issue tracker][issues] for similar issues.
2. Specify the version of Networked-Aframe in which the bug occurred.
3. Specify information about your browser and system (e.g., "Firefox Nightly on OS X")
4. Describe the problem in detail (i.e., what happened and what you expected would happen).
5. If possible, provide a small test case with [Glitch](http://glitch.com), a link to your application, and/or a screenshot. You can fork/remix this [Glitch project](https://glitch.com/edit/#!/networked-aframe).

# Contribute Code to Networked-Aframe

[naf]: https://github.com/networked-aframe/networked-aframe
[aframe]: https://github.com/aframevr/aframe/
[pr]: https://www.digitalocean.com/community/tutorials/how-to-create-a-pull-request-on-github
[ssh]: https://help.github.com/articles/generating-a-new-ssh-key-and-adding-it-to-the-ssh-agent/
[tests]: https://github.com/aframevr/aframe/tree/master/tests#a-frame-unit-tests
[tutorial]: https://github.com/networked-aframe/networked-aframe/blob/master/docs/getting-started-local.md

Here's how to submit a pull request (PR):

1. Have a [GitHub account](https://github.com/join) with [SSH keys][ssh] set up.
2. [Fork](https://github.com/networked-aframe/networked-aframe/fork) the repository on GitHub.
3. Clone your fork of the repository locally (i.e., `git clone git@github.com:yourusername/networked-aframe`).
4. Run `npm install` to get dependencies and `npm run dev` to serve the test examples. [Follow this tutorial on how to get started][tutorial]
5. Create a branch to work in (i.e., `git checkout -b mybranch`).
6. Make changes to your fork of the repository, commit them, and push them (i.e., `git add -A . && git commit -m 'My Changes (fixes #1234)' && git push origin mybranch`).
7. If necessary, write [unit tests](tests/unit/) <!-- ([guide][tests]) --> and run with `npm run test`.
8. Make sure your code follows codestyle of the rest of the project.
9. If your commit changes the external API of Networked-Aframe update the [documentation][README]
9. [Submit a pull request][pr] to the master branch. If you head to the [Networked-Aframe repository][naf] after running `git push` from earlier, you should see a pop up to submit a pull request.
10. [Address review comments](http://stackoverflow.com/questions/9790448/how-to-update-a-pull-request) if any.

As per usual with open source, you would agree to license your contributions
under the [MIT License](LICENSE).

# Share your Work

1. Create something awesome with networked-aframe
2. Publish your work to Github (and GitHub pages) so everyone can learn from your work.
3. Share it on [Slack](https://aframe.io/slack-invite/), Twitter, or the [awesome-aframe repository](https://github.com/aframevr/awesome-aframe).
4. Let A-Frame know about it so they can feature it on their blog: [A Week of A-Frame](https://aframe.io/blog/).
4. For bonus points, write and publish a case study to explain how you built it.

# Help Your Fellow A-Framers

## On Slack

1. [Invite yourself](https://aframe.io/slack-invite/) to the A-Frame Slack channel.
2. Join the #networked-aframe channel
3. Help answer questions that people might have and welcome new people.

## On GitHub

1. Help respond to [newly-filed GitHub issues][issues]

# Curate and Make Efforts Known

Every week, the A-Frame team rounds up all the cool stuff happening with A-Frame on their
[blog](https://aframe.io/blog). They collect things to show off in [these GitHub
issues](https://github.com/aframevr/aframe-site/labels/A%20Week%20of%20A-Frame).
If you see anything, just post it there!

Also feel free to message head NAF maintainer [Hayden on twitter][hayden]!

# Spread the Word

If you want to hold an event and talk about WebVR, A-Frame and/or Networked-Aframe, check out [the
presentation kit](https://github.com/aframevr/aframe-presentation-kit).

Thanks so much for contributing and helping grow WebVR!

==> networked-aframe-0.8.3.tgz: package/CONTRIBUTING.md <==
[slack]: https://aframe.io/slack-invite/
[issues]: https://github.com/networked-aframe/networked-aframe/issues

Interested in contributing? As an open source project, we'd appreciate any help
and contributions! On top of the Networked-Aframe framework itself, you can also
contribute to this related component:

- [aframe-lerp-component](https://github.com/haydenjameslee/aframe-lerp-component)

# Join the Community on Slack

1. [Invite yourself][slack] to the A-Frame Slack channel.
2. [Join the A-Frame slack](https://aframevr.slack.com)
3. Join the #networked-aframe channel

# Get Help or Ask a Question

If you're not sure how to do something with Networked-Aframe, please post a question
(and any code you've tried so far) to [Github Issues][issues]. <!-- Questions there will automatically create notifications in [Slack][slack], and are easier for others to find so new developers can learn from your questions too. -->

# File an Issue

1. Search the [issue tracker][issues] for similar issues.
2. Specify the version of Networked-Aframe in which the bug occurred.
3. Specify information about your browser and system (e.g., "Firefox Nightly on OS X")
4. Describe the problem in detail (i.e., what happened and what you expected would happen).
5. If possible, provide a small test case with [Glitch](http://glitch.com), a link to your application, and/or a screenshot. You can fork/remix this [Glitch project](https://glitch.com/edit/#!/naf-project).

# Contribute Code to Networked-Aframe

[README]: https://github.com/networked-aframe/networked-aframe/blob/master/README.md
[naf]: https://github.com/networked-aframe/networked-aframe
[aframe]: https://github.com/aframevr/aframe/
[pr]: https://www.digitalocean.com/community/tutorials/how-to-create-a-pull-request-on-github
[ssh]: https://help.github.com/articles/generating-a-new-ssh-key-and-adding-it-to-the-ssh-agent/
[tests]: https://github.com/aframevr/aframe/tree/master/tests#a-frame-unit-tests
[tutorial]: https://github.com/networked-aframe/networked-aframe/blob/master/docs/getting-started-local.md

Here's how to submit a pull request (PR):

1. Have a [GitHub account](https://github.com/join) with [SSH keys][ssh] set up.
2. [Fork](https://github.com/networked-aframe/networked-aframe/fork) the repository on GitHub.
3. Clone your fork of the repository locally (i.e., `git clone git@github.com:yourusername/networked-aframe`).
4. Run `npm install` to get dependencies and `npm run dev` to serve the test examples. [Follow this tutorial on how to get started][tutorial]
5. Create a branch to work in (i.e., `git checkout -b mybranch`).
6. Make changes to your fork of the repository, commit them, and push them (i.e., `git add -A . && git commit -m 'My Changes (fixes #1234)' && git push origin mybranch`).
7. If necessary, write [unit tests](tests/unit/) <!-- ([guide][tests]) --> and run with `npm run test`.
8. Make sure your code follows codestyle of the rest of the project.
9. If your commit changes the external API of Networked-Aframe update the [documentation][README]
9. [Submit a pull request][pr] to the master branch. If you head to the [Networked-Aframe repository][naf] after running `git push` from earlier, you should see a pop up to submit a pull request.
10. [Address review comments](http://stackoverflow.com/questions/9790448/how-to-update-a-pull-request) if any.

As per usual with open source, you would agree to license your contributions
under the [MIT License](LICENSE).

# Share your Work

1. Create something awesome with networked-aframe
2. Publish your work to Github (and GitHub pages) so everyone can learn from your work.
3. Share it on [Slack](https://aframe.io/slack-invite/) on the #projects channel.
4. Let A-Frame know about it so they can feature it on their blog: [A Week of A-Frame](https://aframe.io/blog/). For this just tweet your project with a small video to @aframevr
4. For bonus points, write and publish a case study to explain how you built it.

# Help Your Fellow A-Framers

## On Slack

1. [Invite yourself](https://aframe.io/slack-invite/) to the A-Frame Slack channel.
2. Join the #networked-aframe channel
3. Help answer questions that people might have and welcome new people.

## On GitHub

1. Help respond to [newly-filed GitHub issues][issues]

# Curate and Make Efforts Known

Every week, the A-Frame team rounds up all the cool stuff happening with A-Frame on their
[blog](https://aframe.io/blog). If you tweeted about it and added a comment on Slack,
there is a good chance for it to be included in the next blog post.

Also feel free to message us on #networked-aframe channel on [Slack](https://aframe.io/slack-invite/).

# Spread the Word

If you want to hold an event and talk about WebVR, A-Frame and/or Networked-Aframe, check out [the
presentation kit](https://github.com/aframevr/aframe-presentation-kit).

Thanks so much for contributing and helping grow WebXR!
